/* FreeRTOS LM3S-6965 Minimal example */

/* Standard includes. */
#include <stdio.h>

/* Scheduler includes. */
#include "FreeRTOS.h"
#include "task.h"
#include "queue.h"
#include "semphr.h"

/* Hardware library includes. */
#include "hw_memmap.h"
#include "hw_types.h"
#include "hw_sysctl.h"
#include "sysctl.h"
#include "gpio.h"
#include "osram128x64x4.h"



/*-----------------------------------------------------------*/


/*
 * Configure the hardware for the demo.
 */
static void prvSetupHardware( void );

/*
 * Hook functions that can get called by the kernel.
 */
void vApplicationStackOverflowHook( xTaskHandle *pxTask, signed portCHAR *pcTaskName );
void vApplicationTickHook( void );




void prvSetupHardware( void )
{
    /* If running on Rev A2 silicon, turn the LDO voltage up to 2.75V.  This is
    a workaround to allow the PLL to operate reliably. */
    if( DEVICE_IS_REVA2 )
    {
        SysCtlLDOSet( SYSCTL_LDO_2_75V );
    }
	
	/* Set the clocking to run from the PLL at 50 MHz */
	SysCtlClockSet( SYSCTL_SYSDIV_4 | SYSCTL_USE_PLL | SYSCTL_OSC_MAIN | SYSCTL_XTAL_8MHZ );
	
    OSRAM128x64x4Init(1000000);
	
//	vParTestInitialise();
}
/*-----------------------------------------------------------*/






void prvTaskA (void* pvParameters)
{		
    (void) pvParameters;                    // Just to stop compiler warnings.
	
    for (;;) {
        vTaskDelay(500);
        OSRAM128x64x4StringDraw("Hello prvTaskA!", 30, 24, 15);;
        vTaskDelay(500);
    }
}

void prvTaskB (void* pvParameters)
{
    (void) pvParameters;                    // Just to stop compiler warnings.

    for (;;) {
        OSRAM128x64x4StringDraw("Hello prvTaskB", 30, 24, 15);
        vTaskDelay(1000);
    }
}

int main (void)
{
//    vUartInit();
		prvSetupHardware();
	
    xTaskCreate( prvTaskA, ( signed char * ) "TaskA", configMINIMAL_STACK_SIZE, NULL,
        tskIDLE_PRIORITY, ( xTaskHandle * ) NULL );
    xTaskCreate( prvTaskB, ( signed char * ) "TaskB", configMINIMAL_STACK_SIZE, NULL, 
        tskIDLE_PRIORITY, ( xTaskHandle * ) NULL );

    vTaskStartScheduler();

   //should never get here
		OSRAM128x64x4StringDraw("Error", 30, 24, 15);
   for (;;);
}

void vApplicationTickHook( void )
{

}
/*-----------------------------------------------------------*/

void vApplicationStackOverflowHook( xTaskHandle *pxTask, signed portCHAR *pcTaskName )
{
	( void ) pxTask;
	( void ) pcTaskName;

	for( ;; );
}










